import { CustomEmailSenderTriggerEvent, CustomMessageTriggerEvent, PostAuthenticationTriggerEvent, PostConfirmationTriggerEvent, PreSignUpTriggerEvent, PreTokenGenerationTriggerEvent, UserMigrationTriggerEvent } from "aws-lambda";
import type { Lambda as LambdaClient } from "aws-sdk";
import { Context } from "./context";
interface EventCommonParameters {
    clientId: string;
    userAttributes: Record<string, string>;
    username: string;
    userPoolId: string;
}
interface CustomEmailSenderEvent extends Omit<EventCommonParameters, "clientId"> {
    clientId: string | null;
    code: string;
    clientMetadata: Record<string, string> | undefined;
    triggerSource: "CustomEmailSender_AdminCreateUser" | "CustomEmailSender_ForgotPassword" | "CustomEmailSender_ResendCode" | "CustomEmailSender_SignUp" | "CustomEmailSender_UpdateUserAttribute" | "CustomEmailSender_VerifyUserAttribute";
}
interface CustomMessageEvent extends Omit<EventCommonParameters, "clientId"> {
    clientId: string | null;
    clientMetadata: Record<string, string> | undefined;
    codeParameter: string;
    triggerSource: "CustomMessage_AdminCreateUser" | "CustomMessage_Authentication" | "CustomMessage_ForgotPassword" | "CustomMessage_ResendCode" | "CustomMessage_SignUp" | "CustomMessage_UpdateUserAttribute" | "CustomMessage_VerifyUserAttribute";
    usernameParameter: string;
}
interface UserMigrationEvent extends EventCommonParameters {
    clientMetadata: Record<string, string> | undefined;
    password: string;
    triggerSource: "UserMigration_Authentication";
    validationData: Record<string, string> | undefined;
}
interface PreSignUpEvent extends EventCommonParameters {
    clientMetadata: Record<string, string> | undefined;
    triggerSource: "PreSignUp_AdminCreateUser" | "PreSignUp_ExternalProvider" | "PreSignUp_SignUp";
    validationData: Record<string, string> | undefined;
}
interface PreTokenGenerationEvent extends EventCommonParameters {
    /**
     * One or more key-value pairs that you can provide as custom input to the Lambda function that you specify for the
     * pre token generation trigger. You can pass this data to your Lambda function by using the ClientMetadata parameter
     * in the AdminRespondToAuthChallenge and RespondToAuthChallenge API actions.
     */
    clientMetadata: Record<string, string> | undefined;
    triggerSource: "TokenGeneration_AuthenticateDevice" | "TokenGeneration_Authentication" | "TokenGeneration_HostedAuth" | "TokenGeneration_NewPasswordChallenge" | "TokenGeneration_RefreshTokens";
    /**
     * The input object containing the current group configuration. It includes groupsToOverride, iamRolesToOverride, and
     * preferredRole.
     */
    groupConfiguration: {
        /**
         * A list of the group names that are associated with the user that the identity token is issued for.
         */
        groupsToOverride: readonly string[] | undefined;
        /**
         * A list of the current IAM roles associated with these groups.
         */
        iamRolesToOverride: readonly string[] | undefined;
        /**
         * A string indicating the preferred IAM role.
         */
        preferredRole: string | undefined;
    };
}
interface PostAuthenticationEvent extends EventCommonParameters {
    clientMetadata: Record<string, string> | undefined;
    triggerSource: "PostAuthentication_Authentication";
}
interface PostConfirmationEvent extends Omit<EventCommonParameters, "clientId"> {
    triggerSource: "PostConfirmation_ConfirmSignUp" | "PostConfirmation_ConfirmForgotPassword";
    clientMetadata: Record<string, string> | undefined;
    clientId: string | null;
}
export interface FunctionConfig {
    CustomMessage?: string;
    PostAuthentication?: string;
    PostConfirmation?: string;
    PreSignUp?: string;
    PreTokenGeneration?: string;
    UserMigration?: string;
    CustomEmailSender?: string;
}
export declare type CustomMessageTriggerResponse = CustomMessageTriggerEvent["response"];
export declare type UserMigrationTriggerResponse = UserMigrationTriggerEvent["response"];
export declare type PreSignUpTriggerResponse = PreSignUpTriggerEvent["response"];
export declare type PreTokenGenerationTriggerResponse = PreTokenGenerationTriggerEvent["response"];
export declare type PostAuthenticationTriggerResponse = PostAuthenticationTriggerEvent["response"];
export declare type PostConfirmationTriggerResponse = PostConfirmationTriggerEvent["response"];
export declare type CustomEmailSenderTriggerResponse = CustomEmailSenderTriggerEvent["response"];
export interface Lambda {
    enabled(lambda: keyof FunctionConfig): boolean;
    invoke(ctx: Context, lambda: "CustomMessage", event: CustomMessageEvent): Promise<CustomMessageTriggerResponse>;
    invoke(ctx: Context, lambda: "UserMigration", event: UserMigrationEvent): Promise<UserMigrationTriggerResponse>;
    invoke(ctx: Context, lambda: "PreSignUp", event: PreSignUpEvent): Promise<PreSignUpTriggerResponse>;
    invoke(ctx: Context, lambda: "PreTokenGeneration", event: PreTokenGenerationEvent): Promise<PreTokenGenerationTriggerResponse>;
    invoke(ctx: Context, lambda: "PostAuthentication", event: PostAuthenticationEvent): Promise<PostAuthenticationTriggerResponse>;
    invoke(ctx: Context, lambda: "PostConfirmation", event: PostConfirmationEvent): Promise<PostConfirmationTriggerResponse>;
    invoke(ctx: Context, lambda: "CustomEmailSender", event: CustomEmailSenderEvent): Promise<CustomEmailSenderTriggerResponse>;
}
export declare class LambdaService implements Lambda {
    private readonly config;
    private readonly lambdaClient;
    constructor(config: FunctionConfig, lambdaClient: LambdaClient);
    enabled(lambda: keyof FunctionConfig): boolean;
    invoke(ctx: Context, trigger: keyof FunctionConfig, event: CustomMessageEvent | CustomEmailSenderEvent | PostAuthenticationEvent | PostConfirmationEvent | PreSignUpEvent | PreTokenGenerationEvent | UserMigrationEvent): Promise<any>;
    private createLambdaEvent;
}
export {};
