import { AttributeListType, AttributeType, MFAOptionListType, SchemaAttributesListType, StringType, UserMFASettingListType, UserPoolType, UserStatusType } from "aws-sdk/clients/cognitoidentityserviceprovider";
import { AppClient } from "./appClient";
import { Clock } from "./clock";
import { Context } from "./context";
import { DataStore } from "./dataStore/dataStore";
import { DataStoreFactory } from "./dataStore/factory";
export interface MFAOption {
    DeliveryMedium: "SMS";
    AttributeName: "phone_number";
}
export declare const attribute: (name: string, value: string | undefined) => AttributeType;
export declare const attributesIncludeMatch: (attributeName: string, attributeValue: string, attributes: AttributeListType | undefined) => boolean;
export declare const attributesInclude: (attributeName: string, attributes: AttributeListType | undefined) => boolean;
export declare const attributeValue: (attributeName: string | undefined, attributes: AttributeListType | undefined) => string | undefined;
export declare const attributesToRecord: (attributes: AttributeListType | undefined) => Record<string, string>;
export declare const attributesFromRecord: (attributes: Record<string, string>) => AttributeListType;
export declare const attributesAppend: (attributes: AttributeListType | undefined, ...toAppend: AttributeListType) => AttributeListType;
export declare const attributesRemove: (attributes: AttributeListType | undefined, ...toRemove: readonly string[]) => AttributeListType;
export declare const customAttributes: (attributes: AttributeListType | undefined) => AttributeListType;
export interface User {
    Attributes: AttributeListType;
    Enabled: boolean;
    MFAOptions?: MFAOptionListType;
    PreferredMfaSetting?: StringType;
    UserCreateDate: Date;
    UserLastModifiedDate: Date;
    UserMFASettingList?: UserMFASettingListType;
    Username: string;
    UserStatus: UserStatusType;
    Password: string;
    AttributeVerificationCode?: string;
    ConfirmationCode?: string;
    MFACode?: string;
    RefreshTokens: string[];
}
export interface Group {
    /**
     * The name of the group.
     */
    GroupName: string;
    /**
     * A string containing the description of the group.
     */
    Description?: string;
    /**
     * The role ARN for the group.
     */
    RoleArn?: string;
    /**
     * A nonnegative integer value that specifies the precedence of this group relative to the other groups that a user can belong to in the user pool. If a user belongs to two or more groups, it is the group with the highest precedence whose role ARN will be used in the cognito:roles and cognito:preferred_role claims in the user's tokens. Groups with higher Precedence values take precedence over groups with lower Precedence values or with null Precedence values. Two groups can have the same Precedence value. If this happens, neither group takes precedence over the other. If two groups with the same Precedence have the same role ARN, that role is used in the cognito:preferred_role claim in tokens for users in each group. If the two groups have different role ARNs, the cognito:preferred_role claim is not set in users' tokens. The default Precedence value is null.
     */
    Precedence?: number;
    /**
     * The date the group was last modified.
     */
    LastModifiedDate: Date;
    /**
     * The date the group was created.
     */
    CreationDate: Date;
    /**
     * The group's membership, a list of Usernames
     */
    members?: readonly string[];
}
export declare type UserPool = UserPoolType & {
    Id: string;
};
export interface UserPoolService {
    readonly options: UserPool;
    addUserToGroup(ctx: Context, group: Group, user: User): Promise<void>;
    saveAppClient(ctx: Context, appClient: AppClient): Promise<void>;
    deleteAppClient(ctx: Context, appClient: AppClient): Promise<void>;
    deleteGroup(ctx: Context, group: Group): Promise<void>;
    deleteUser(ctx: Context, user: User): Promise<void>;
    getGroupByGroupName(ctx: Context, groupName: string): Promise<Group | null>;
    getUserByUsername(ctx: Context, username: string): Promise<User | null>;
    getUserByRefreshToken(ctx: Context, refreshToken: string): Promise<User | null>;
    listGroups(ctx: Context): Promise<readonly Group[]>;
    listUsers(ctx: Context): Promise<readonly User[]>;
    listUserGroupMembership(ctx: Context, user: User): Promise<readonly string[]>;
    updateOptions(ctx: Context, userPool: UserPool): Promise<void>;
    removeUserFromGroup(ctx: Context, group: Group, user: User): Promise<void>;
    saveGroup(ctx: Context, group: Group): Promise<void>;
    saveUser(ctx: Context, user: User): Promise<void>;
    storeRefreshToken(ctx: Context, refreshToken: string, user: User): Promise<void>;
}
export interface UserPoolServiceFactory {
    create(ctx: Context, clientsDataStore: DataStore, defaultOptions: UserPool): Promise<UserPoolService>;
}
export declare class UserPoolServiceImpl implements UserPoolService {
    private readonly clientsDataStore;
    private readonly clock;
    private readonly dataStore;
    private _options;
    get options(): UserPool;
    constructor(clientsDataStore: DataStore, clock: Clock, dataStore: DataStore, config: UserPool);
    saveAppClient(ctx: Context, appClient: AppClient): Promise<void>;
    deleteAppClient(ctx: Context, appClient: AppClient): Promise<void>;
    deleteGroup(ctx: Context, group: Group): Promise<void>;
    deleteUser(ctx: Context, user: User): Promise<void>;
    getGroupByGroupName(ctx: Context, groupName: string): Promise<Group | null>;
    getUserByUsername(ctx: Context, username: string): Promise<User | null>;
    getUserByRefreshToken(ctx: Context, refreshToken: string): Promise<User | null>;
    listUsers(ctx: Context): Promise<readonly User[]>;
    updateOptions(ctx: Context, userPool: UserPool): Promise<void>;
    saveUser(ctx: Context, user: User): Promise<void>;
    listGroups(ctx: Context): Promise<readonly Group[]>;
    addUserToGroup(ctx: Context, group: Group, user: User): Promise<void>;
    removeUserFromGroup(ctx: Context, group: Group, user: User): Promise<void>;
    private removeUserFromAllGroups;
    saveGroup(ctx: Context, group: Group): Promise<void>;
    listUserGroupMembership(ctx: Context, user: User): Promise<readonly string[]>;
    storeRefreshToken(ctx: Context, refreshToken: string, user: User): Promise<void>;
}
export declare class UserPoolServiceFactoryImpl implements UserPoolServiceFactory {
    private readonly clock;
    private readonly dataStoreFactory;
    constructor(clock: Clock, dataStoreFactory: DataStoreFactory);
    create(ctx: Context, clientsDataStore: DataStore, defaultOptions: UserPool): Promise<UserPoolService>;
}
export declare const validatePermittedAttributeChanges: (requestAttributes: AttributeListType, schemaAttributes: SchemaAttributesListType) => AttributeListType;
export declare const defaultVerifiedAttributesIfModified: (attributes: AttributeListType) => AttributeListType;
export declare const hasUnverifiedContactAttributes: (userAttributesToSet: AttributeListType) => boolean;
